==> mongo-tools-3.0.14.tar.gz: mongo-tools-r3.0.14/test/legacy24/jstests/tool/dumprestoreWithNoOptions.js <==
// SERVER-6366
// relates to SERVER-808
//
// This file tests that options are not restored upon
// mongorestore with --noOptionsRestore
//
// It checks that this works both when doing a full
// database dump/restore and when doing it just for a
// single db or collection.

t = new ToolTest( "dumprestoreWithNoOptions" );

t.startDB( "foo" );
db = t.db;

dbname = db.getName();
dbname2 = "NOT_"+dbname;

db.dropDatabase();

var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

// Full dump/restore

t.runTool( "dump" , "--out" , t.ext );

db.dropDatabase();
assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore" , "--dir" , t.ext , "--noOptionsRestore");

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert(true !== db.capped.stats().capped, "restore options were not ignored");
assert(undefined === db.capped.exists().options, "restore options not ignored");

// Dump/restore single DB

db.dropDatabase();
var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

dumppath = t.ext + "noOptionsSingleDump/";
mkdir(dumppath);
t.runTool( "dump" , "-d", dbname, "--out" , dumppath );

db.dropDatabase();
assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore" , "-d", dbname2, "--dir" , dumppath + dbname, "--noOptionsRestore");

db = db.getSiblingDB(dbname2);

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert(true !== db.capped.stats().capped, "restore options were not ignored");
assert(undefined === db.capped.exists().options, "restore options not ignored");

// Dump/restore single collection

db.dropDatabase();
var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

dumppath = t.ext + "noOptionsSingleColDump/";
mkdir(dumppath);
dbname = db.getName();
t.runTool( "dump" , "-d", dbname, "-c", "capped", "--out" , dumppath );

db.dropDatabase();

assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore", "-d", dbname, "--drop", "--noOptionsRestore", "--dir", dumppath + dbname );

db = db.getSiblingDB(dbname);

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert( true !== db.capped.stats().capped, "restore options were not ignored" );
assert( undefined === db.capped.exists().options );

t.stop();

==> mongo-tools-3.4.13.tar.gz: mongo-tools-r3.4.13/test/legacy24/jstests/tool/dumprestoreWithNoOptions.js <==
// SERVER-6366
// relates to SERVER-808
//
// This file tests that options are not restored upon
// mongorestore with --noOptionsRestore
//
// It checks that this works both when doing a full
// database dump/restore and when doing it just for a
// single db or collection.

t = new ToolTest( "dumprestoreWithNoOptions" );

t.startDB( "foo" );
db = t.db;

dbname = db.getName();
dbname2 = "NOT_"+dbname;

db.dropDatabase();

var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

// Full dump/restore

t.runTool( "dump" , "--out" , t.ext );

db.dropDatabase();
assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore" , "--dir" , t.ext , "--noOptionsRestore", "-vvv");

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert(true !== db.capped.stats().capped, "restore options were not ignored");

// Note: The 2.4 server seems to have a bug where part of the "create" command
// itself ends up being set in the collection options object. So as a workaround,
// we will just delete that key and make sure there are no other keys set in
// the options object.
opts = db.capped.exists().options;
delete opts.create;
assert.eq(Object.keys(opts).length, 0, "restore options not ignored");

// Dump/restore single DB

db.dropDatabase();
var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

dumppath = t.ext + "noOptionsSingleDump/";
mkdir(dumppath);
t.runTool( "dump" , "-d", dbname, "--out" , dumppath );

db.dropDatabase();
assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore" , "-d", dbname2, "--dir" , dumppath + dbname, "--noOptionsRestore");

db = db.getSiblingDB(dbname2);

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert(true !== db.capped.stats().capped, "restore options were not ignored");

opts = db.capped.exists().options;
delete opts.create;
assert.eq(Object.keys(opts).length, 0, "restore options not ignored");

// Dump/restore single collection

db.dropDatabase();
var options = { capped: true, size: 1000, autoIndexId: true };
db.createCollection('capped', options);
assert.eq( 1, db.system.indexes.count(), "auto index not created" );
var cappedOptions = db.capped.exists().options;
for ( var opt in options ) {
  assert.eq(options[opt], cappedOptions[opt], 'invalid option')
}
db.capped.insert({ x: 1 });
db.getLastError()

dumppath = t.ext + "noOptionsSingleColDump/";
mkdir(dumppath);
dbname = db.getName();
t.runTool( "dump" , "-d", dbname, "-c", "capped", "--out" , dumppath );

db.dropDatabase();

assert.eq( 0, db.capped.count(), "capped not dropped");
assert.eq( 0, db.system.indexes.count(), "indexes not dropped" );

t.runTool( "restore", "-d", dbname, "--drop", "--noOptionsRestore", "--dir", dumppath + dbname );

db = db.getSiblingDB(dbname);

assert.eq( 1, db.capped.count() , "wrong number of docs restored to capped" );
assert( true !== db.capped.stats().capped, "restore options were not ignored" );
opts = db.capped.exists().options;
delete opts.create;
assert.eq(Object.keys(opts).length, 0, "restore options not ignored");

t.stop();
